"""Table names for the database models."""

PROJECT_TABLE_NAME = "projects"
SPAN_TABLE_NAME = "spans"
GENERATION_TABLE_NAME = "generations"
PROMPT_TABLE_NAME = "prompts"
USER_TABLE_NAME = "users"
ORGANIZATION_TABLE_NAME = "organizations"
USER_ORGANIZATION_TABLE_NAME = "user_organizations"
RESPONSE_MODEL_TABLE_NAME = "response_models"
API_KEY_TABLE_NAME = "api_keys"
ANNOTATION_TABLE_NAME = "annotations"
ORGANIZATION_INVITE_TABLE_NAME = "organization_invites"
